/* $Id: init.c,v 1.3 2000/03/31 05:20:11 ajapted Exp $
******************************************************************************

   LibGFFD - initialisation

   Copyright (C) 2000  Andrew Apted   [andrew.apted@ggi-project.org]
   
   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#define GD_DEBUG_PKG    "LibGFFD"
#define GD_DEBUG_LEVEL	0

#include <stdio.h>
#include <stdlib.h>

#include "internal.h"


static const char *ruleset_filename = GFFDCONFDIR "/" GFFDCONFFILE;


int gffdInit(void)
{
  _gffdInitRules();

  return _gffdLoadRules(ruleset_filename);
}

int gffdExit(void)
{
  _gffdFreeRules();

  return 0;
}


/* ---------------------------------------------------------------- */


gffd_context_t gffdNewContext(void)
{
  gffd_context *ctx;

  ctx = (gffd_context *) calloc(1, sizeof(gffd_context));

  return ctx;
}

int gffdFreeContext(gffd_context_t ctx)
{
  if (ctx->begun)
    gffdEnd(ctx);
  
  free(ctx);

  return 0;
}

int gffdSetOption(gffd_context_t ctx, int option, int value)
{
  return GFFD_E_BAD_OPT;
}

int gffdGetOption(gffd_context_t ctx, int option)
{
  return GFFD_E_BAD_OPT;
}

int gffdBegin(gffd_context_t ctx)
{
  if (ctx->begun)
    return GFFD_E_BAD_PLACE;
  
  ctx->begun = 1;
  ctx->full_set = 1;
  ctx->done_names = ctx->done_magic = 0;

  return 0;
}

int gffdEnd(gffd_context_t ctx)
{
  if (! ctx->begun)
    return GFFD_E_BAD_PLACE;
  
  ctx->begun = 0;
  
  if (ctx->full_set)
    return 0;
  
  GD_ASSERT(ctx->matches);

  free(ctx->matches);
  ctx->matches = NULL;

  return 0;
}

